'use strict';
/* eslint no-console: 0 */

var colors = require('chalk');

var updateWebpackConfig = require('./updateWebpackConfig');

var webpack = require('webpack');
/**
 * Create webpack compiler instance
 *
 * @param  {Object} webpackConfig webpack config
 * @return {compiler}             webpack compiler instance
 *
 * @see http://webpack.github.io/docs/plugins.html#the-compiler-instance
 */


module.exports = function (webpackConfig) {
  var compiler;
  var config = updateWebpackConfig(webpackConfig);

  try {
    compiler = webpack(config);
  } catch (err) {
    console.error(colors.red('[ERR]: Failed to compile.'));
    console.log('');
    console.error(err.message || err);
    console.log('');
    process.exit(1);
  }

  compiler.plugin('done', function (stats) {
    if (stats.hasErrors()) {
      return console.error(stats.toString({
        colors: true
      }));
    }

    console.log(stats.toString({
      colors: true,
      chunks: false,
      assets: true
    }));
  });
  compiler.plugin('failed', function (err) {
    throw err;
  });
  return compiler;
};